library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;

library uvvm_vvc_framework;
use uvvm_vvc_framework.ti_vvc_framework_support_pkg.all;

library uvvm_util;

context uvvm_util.uvvm_util_context;

--library bitvis_vip_clock_generator;
--use bitvis_vip_clock_generator.clock_generator_vvc;

library bitvis_vip_axilite;
use bitvis_vip_axilite.axilite_bfm_pkg.all;



library work;
use work.all;


entity	test_harness is

end entity;

architecture behv of test_harness is
constant AXI_BFM_CONFIG : t_axilite_bfm_config := (
    max_wait_cycles             => 400,
    max_wait_cycles_severity    => TB_FAILURE,
    clock_period                => 10 ns,
    clock_period_margin         => 0 ns,
    clock_margin_severity       => TB_ERROR,
    setup_time                  => 2.5 ns,
    hold_time                   => 2.5 ns,
    expected_response           => OKAY,
    expected_response_severity  => TB_FAILURE,
    protection_setting          => UNPRIVILEGED_NONSECURE_DATA,
    num_aw_pipe_stages          => 1,
    num_w_pipe_stages           => 1,
    num_ar_pipe_stages          => 1,
    num_r_pipe_stages           => 1,
    num_b_pipe_stages           => 1,
    id_for_bfm                  => ID_BFM,
    id_for_bfm_wait             => ID_BFM_WAIT,
    id_for_bfm_poll             => ID_BFM_POLL,
    bfm_sync                    => SYNC_ON_CLOCK_ONLY,
    match_strictness            => MATCH_EXACT
    );
constant AXI_ADDR_WIDTH : integer  := 16;
constant AXI_DATA_WIDTH : integer  := 32;
constant AXI_STRB_WIDTH : integer  := AXI_DATA_WIDTH/8;




signal clk : std_logic := '0';
signal reset :std_logic := '1';

-- from bitvis library
signal axi_ctrl_v : t_axilite_if(
        write_address_channel  (awaddr(AXI_ADDR_WIDTH-1 downto 0)),
        write_data_channel     (wdata (AXI_DATA_WIDTH-1 downto 0), wstrb(AXI_STRB_WIDTH -1 downto 0)),
        read_address_channel   (araddr(AXI_ADDR_WIDTH-1 downto 0)),
    	read_data_channel      (rdata (AXI_DATA_WIDTH-1 downto 0))
  );


begin

clk <= not clk after 10 ns;

reset	<= '0' after 100 ns;


--uvvm test component
axi_master :entity bitvis_vip_axilite.axilite_vvc
  generic map(
    GC_ADDR_WIDTH                            => AXI_ADDR_WIDTH,
    GC_DATA_WIDTH                            => AXI_DATA_WIDTH,
    GC_INSTANCE_IDX                          => 1,                             -- Instance index for this AXILITE_VVCT instance
    GC_AXILITE_CONFIG                        => AXI_BFM_CONFIG,  -- Behavior specification for BFM
    GC_CMD_QUEUE_COUNT_MAX                   => 1000,
    GC_CMD_QUEUE_COUNT_THRESHOLD             => 950,
    --GC_CMD_QUEUE_COUNT_THRESHOLD_SEVERITY    => WARNING,
    GC_RESULT_QUEUE_COUNT_MAX                => 1000,
    GC_RESULT_QUEUE_COUNT_THRESHOLD          => 950
    --GC_RESULT_QUEUE_COUNT_THRESHOLD_SEVERITY => WARNING
  )
  port map(
    clk      => clk,
    axilite_vvc_master_if => axi_ctrl_v
  );


end architecture;

